@@ -32,11 +32,11 @@ class GammaCtrl : public QWidget  {
   Q_OBJECT
   public:
     /** construktor */
-    GammaCtrl(QWidget *parent=0, XVidExtWrap *xvid=0, int channel=0, 
+    explicit GammaCtrl(QWidget *parent=nullptr, XVidExtWrap *xvid=nullptr, int channel=0,
       const QString& mingamma="0.40", const QString& maxgamma="3.50", 
       const QString& setgamma="1.00");
     /** destruktor */
-    ~GammaCtrl();
+    ~GammaCtrl() override;
     /** Return the current gamma value with precision prec */
     QString gamma(int);
     /** Set gamma, slider and textfield */
@@ -44,7 +44,7 @@ class GammaCtrl : public QWidget  {
     /** Set slider and textfield */
     void setControl(const QString&);
     /** Disable the slider */
-    void disableSlider() { slider->setDisabled(true);};
+    void disableSlider() { slider->setDisabled(true);}
 
   private:
     QString mgamma;
